# Code of Conduct

## Purpose

This code of conduct outlines expectations for behaviour when participating in the project with the aim of fostering a constructive and professional engineering environment.

## Expected Behaviour

Participants are expected to:

- Be respectful in communication and collaboration.
- Focus on technical topics and project goals.
- Accept constructive feedback gracefully and offer it in kind.
- Assume good intentions from others and engage with a problem-solving mindset.
- Use appropriate language and conduct in all community spaces.

## Scope

This Code of Conduct applies in all project spaces—online and offline—and also applies when individuals are representing the project in public spaces.

## Enforcement

Project maintainers are responsible for enforcing the code and may take proportionate corrective action in response to unexpected behaviour.

## Attribution

Adapted from the [Contributor Covenant](https://www.contributor-covenant.org), with modifications for brevity and neutrality.
